# Contributing to confingy
We actively welcome contributions to confingy.

## Pull Requests
1. Fork the repo and create your branch from `main`.
2. Please make sure that code changes are accompanied with tests.
3. Ensure that mypy and ruff checks all pass.
4. If you have made notable changes to any APIs, then please update the docs.

## Issues
Please use GitHub Issues for bugs reporting and feature requests. For bugs, you should provide a description and try to create a reproducible example.

## Coding Guidelines
- We abide by [ruff](https://docs.astral.sh/ruff/) for linting and formatting.
- We're intentionally limiting the number of dependencies.
- We use [Google style docstrings](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings).
